@@ -59,7 +59,20 @@ if (!isGeneric("maxent")) {
 		standardGeneric("maxent"))
 }	
 
+
+.rJava <- function() {
+	if (is.null(getOption('dismo_rJavaLoaded'))) {
+		if ( require(rJava) ) {
+			.jpackage('dismo')
+			options(dismo_rJavaLoaded=TRUE)
+		} else {
+			stop('rJava cannot be loaded')
+		}
+	}
+}
+
 .getMeVersion <- function() {
+	.rJava()
 	mxe <- .jnew("meversion") 
 	v <- try(.jcall(mxe, "S", "meversion") )
 	if (class(v) == 'try-error') {
@@ -73,9 +86,10 @@ if (!isGeneric("maxent")) {
 
 setMethod('maxent', signature(x='missing', p='missing'), 
 	function(x, p, ...) {
+		.rJava()
 		jar <- paste(system.file(package="dismo"), "/java/maxent.jar", sep='')
 		if (!file.exists(jar)) {
-			stop('maxent program is missing:', jar, '.\nPlease download it here: http://www.cs.princeton.edu/~schapire/maxent/')
+			stop('maxent program is missing: ', jar, '\nPlease download it here: http://www.cs.princeton.edu/~schapire/maxent/')
 		}
 		v <- .getMeVersion()
 		cat('This is MaxEnt version', v, '\n' )
@@ -190,11 +204,12 @@ setMethod('maxent', signature(x='Raster', p='ANY'),
 
 setMethod('maxent', signature(x='data.frame', p='vector'), 
 	function(x, p, args=NULL, path, ...) {
-
+	
 		jar <- paste(system.file(package="dismo"), "/java/maxent.jar", sep='')
 		if (!file.exists(jar)) {
 			stop('file missing:\n', jar, '.\nPlease download it here: http://www.cs.princeton.edu/~schapire/maxent/')
 		}
+		.rJava()
 		
 		MEversion <- .getMeVersion()
 
